==> java-checks-3.12-sources.jar: org/sonar/java/checks/xml/maven/ArtifactIdNamingConventionCheck.java <==
/*
 * SonarQube Java
 * Copyright (C) 2012-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.java.checks.xml.maven;

import org.sonar.api.server.rule.RulesDefinition;
import org.sonar.check.Priority;
import org.sonar.check.Rule;
import org.sonar.check.RuleProperty;
import org.sonar.java.tag.Tag;
import org.sonar.maven.model.maven2.MavenProject;
import org.sonar.squidbridge.annotations.SqaleConstantRemediation;
import org.sonar.squidbridge.annotations.SqaleSubCharacteristic;

@Rule(
  key = ArtifactIdNamingConventionCheck.KEY,
  name = "Artifact ids should follow a naming convention",
  priority = Priority.MINOR,
  tags = {Tag.CONVENTION, Tag.MAVEN})
@SqaleSubCharacteristic(RulesDefinition.SubCharacteristics.READABILITY)
@SqaleConstantRemediation("5min")
public class ArtifactIdNamingConventionCheck extends AbstractNamingConvention {

  public static final String KEY = "S3420";
  private static final String DEFAULT_REGEX = "[a-z][a-z-0-9]+";

  @RuleProperty(
    key = "regex",
    description = "The regular expression the \"artifactId\" should match",
    defaultValue = "" + DEFAULT_REGEX)
  public String regex = DEFAULT_REGEX;

  @Override
  protected String getRegex() {
    return regex;
  }

  @Override
  protected String getRuleKey() {
    return KEY;
  }

  @Override
  protected NamedLocatedAttribute getTargetedLocatedAttribute(MavenProject mavenProject) {
    return new NamedLocatedAttribute("artifactId", mavenProject.getArtifactId());
  }

}

==> java-checks-4.4.0.8066-sources.jar: org/sonar/java/checks/xml/maven/ArtifactIdNamingConventionCheck.java <==
/*
 * SonarQube Java
 * Copyright (C) 2012-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.java.checks.xml.maven;

import org.sonar.check.Rule;
import org.sonar.check.RuleProperty;
import org.sonar.maven.model.maven2.MavenProject;

@Rule(key = ArtifactIdNamingConventionCheck.KEY)
public class ArtifactIdNamingConventionCheck extends AbstractNamingConvention {

  public static final String KEY = "S3420";
  private static final String DEFAULT_REGEX = "[a-z][a-z-0-9]+";

  @RuleProperty(
    key = "regex",
    description = "The regular expression the \"artifactId\" should match",
    defaultValue = "" + DEFAULT_REGEX)
  public String regex = DEFAULT_REGEX;

  @Override
  protected String getRegex() {
    return regex;
  }

  @Override
  protected String getRuleKey() {
    return KEY;
  }

  @Override
  protected NamedLocatedAttribute getTargetedLocatedAttribute(MavenProject mavenProject) {
    return new NamedLocatedAttribute("artifactId", mavenProject.getArtifactId());
  }

}
